module syncro(out,in,CLK,RST);
	parameter WIDTH = 1;
	input [WIDTH-1:0] in; 
	output [WIDTH-1:0] out;
	input CLK,RST;
	reg [ WIDTH-1:0] q0,q1,q2;
	always @(posedge CLK or negedge RST)
		begin
			if(!RST)
				q0<=0;
			else
				q0<=~in;
		end
	always @(posedge CLK or negedge RST)
		begin
			if(!RST)
				q1<=0;
			else
				q1<=q0;
		end
	always @(posedge CLK or negedge RST)
		begin
			if(!RST)
				q2<=0;
			else
				q2<=q1;
		end
	assign out=q1&(~q2);
endmodule
module binled(in,ledh,ledl);
  input [6:0] in;
  output [6:0] ledh,ledl;
  wire [3:0] outh,outl;
  bintobcd I0(.in(in),.outl(outl),.outh(outh));
  ledout I1(.in(outl),.out(ledl));
  ledout I2(.in(outh),.out(ledh));
endmodule
module bintobcd(in,outl,outh);
  input [6:0] in;
  output [3:0] outl,outh;
  wire [6:0] tmp1,tmp2,tmp3;
  assign outh[3] = (in>=80)   ? 1       : 0;
  assign tmp1    = (in>=80)   ? in-80   : in;
  assign outh[2] = (tmp1>=40) ? 1       : 0;
  assign tmp2    = (tmp1>=40) ? tmp1-40 : tmp1;
  assign outh[1] = (tmp2>=20) ? 1       : 0;
  assign tmp3    = (tmp2>=20) ? tmp2-20 : tmp2;
  assign outh[0] = (tmp3>=10) ? 1       : 0;
  assign outl    = (tmp3>=10) ? tmp3-10 : tmp3;
endmodule
`define SEG_OUT_0 7'b011_1111
`define SEG_OUT_1 7'b000_0110
`define SEG_OUT_2 7'b101_1011
`define SEG_OUT_3 7'b100_1111
`define SEG_OUT_4 7'b110_0110
`define SEG_OUT_5 7'b110_1101
`define SEG_OUT_6 7'b111_1101
`define SEG_OUT_7 7'b010_0111
`define SEG_OUT_8 7'b111_1111
`define SEG_OUT_9 7'b110_1111
`define SEG_OUT_ERR 7'b011_1001
module ledout(out,in);
 input [3:0] in;
 output [6:0] out;
  function [6:0] convert;
    input [3:0] in ;
     	case (in)
	  0:    convert = `SEG_OUT_0;
	  1:    convert = `SEG_OUT_1;
	  2:    convert = `SEG_OUT_2;
	  3:    convert = `SEG_OUT_3;
	  4:    convert = `SEG_OUT_4;
	  5:    convert = `SEG_OUT_5;
	  6:    convert = `SEG_OUT_6;
	  7:    convert = `SEG_OUT_7;
	  8:    convert = `SEG_OUT_8;
	  9:    convert = `SEG_OUT_9;
default:    convert = `SEG_OUT_ERR;
	//  If the above line is omitted, A warning messsage is shown in Synplify Pro
	endcase
endfunction
    assign out=convert(in);
endmodule
